# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['sqlfmt', 'sqlfmt_primer']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0,<9.0', 'platformdirs>=2.4.0,<3.0.0']

extras_require = \
{':python_version < "3.8"': ['importlib_metadata', 'backports.cached-property'],
 'sqlfmt_primer': ['gitpython>=3.1.24,<4.0.0']}

entry_points = \
{'console_scripts': ['sqlfmt = sqlfmt.cli:sqlfmt',
                     'sqlfmt_primer = sqlfmt_primer.primer:sqlfmt_primer']}

setup_kwargs = {
    'name': 'shandy-sqlfmt',
    'version': '0.4.3',
    'description': 'sqlfmt is an opinionated CLI tool that formats your sql files',
    'long_description': '# sqlfmt\n\n![PyPI](https://img.shields.io/pypi/v/shandy-sqlfmt)\n[![Lint and Test](https://github.com/tconbeer/sqlfmt/actions/workflows/test.yml/badge.svg)](https://github.com/tconbeer/sqlfmt/actions/workflows/test.yml)\n\n![PyPI - Python Version](https://img.shields.io/pypi/pyversions/shandy-sqlfmt)\n![Runs on Linux | MacOS | Windows](https://img.shields.io/badge/runs%20on-Linux%20%7C%20MacOS%20%7C%20Windows-blue)\n\n\nsqlfmt formats your dbt SQL files so you don\'t have to. It is similar in nature to black, gofmt, \nand rustfmt (but for SQL). When you use sqlfmt:\n\n1. You never have to mention (or argue about) code style in code reviews again\n1. You make it easier to collaborate and solicit contributions from new people\n1. You will be able to read your team\'s code as if you wrote it\n1. You can forget about formatting your code, and spend your time on business logic instead\n\nsqlfmt is not configurable, except for line length. It enforces a single style. sqlfmt maintains comments and some extra newlines, but largely ignores all indentation and line breaks in the input file.\n\nsqlfmt is not a linter. It does not parse your code into an AST; it just lexes it and tracks a small subset of tokens that impact formatting. This lets us "do one thing and do it well:" sqlfmt is very fast, and easier to maintain and extend than linters that need a full SQL grammar.\n\nsqlfmt is designed to work with templated SQL files that contain jinja tags and blocks. It formats the code that users look at, and therefore doesn\'t need to know anything about what happens after the templates are rendered.\n\nFor now, sqlfmt only works on `select` statements (which is all you need if you use sqlfmt with a dbt project). In the future, it will be extended to DDL statements, as well.\n\n## Installation\n\n### Try it first\nWant to test out sqlfmt on a query before you install it? Go to [sqlfmt.com](http://sqlfmt.com) to use the interactive, web-based version.\n\n### Prerequisites\nYou will need Python 3.7-3.10 installed. You should use pipx or install into a virtual environment (maybe as a dev-dependency in your project). If you do not know how to install python and use pipx and/or virtual environments, go read about that first.\n\n### Install Using pipx (recommended)\n\n```\npipx install shandy-sqlfmt\n```\n\n### Other Installation Options\nYou should use a virutal environment to isolate sqlfmt\'s dependencies from others on your system. We recommend poetry (`poetry add -D shandy-sqlfmt`), or pipenv (`pipenv install -d shandy-sqlfmt`), but a simple `pip install shandy-sqlfmt` will also work.\n\n## Getting Started\n\n### Other prerequisites\n**sqlfmt is an alpha product** and will not always produce the formatted output you might want. It might even break your SQL syntax. It is **highly recommended** to only run sqlfmt on files in a version control system (like git), so that it is easy for you to revert any changes made by sqlfmt. On your first run, be sure to make a commit before running sqlfmt.\n\n### Using sqlfmt\nsqlfmt is a command-line tool. It works on any posix terminal and on Windows Powershell. If you have used `black`, the sqlfmt commands will look familiar. \n\n> Note: The `$` in the code snippets below indicate that these are commands that can be typed into your terminal. The `$` is the prompt symbol in bash; it is equivalent to `>` on Windows or `%` on zsh. Do not include the `$` in the command you type into your terminal\n\nTo list commands and options:\n\n```bash\n$ sqlfmt --help\n```\n\nIf you want to format all `.sql` and `.sql.jinja` files in your current working directory (and all nested directories), simply type:\n```bash\n$ sqlfmt .\n```\nYou can also supply a path to a one or more files or directories as arguments:\n```bash\n$ sqlfmt /path/to/my/dir /path/to/a/file.sql\n```\nIf you don\'t want to format the files you have on disk, you can run sqlfmt with the `--check` option. sqlfmt will exit with code 1 if the files on disk are not properly formatted:\n```bash\n$ sqlfmt --check .\n$ sqlfmt --check path/to/my/dir\n```\nIf you want to print a diff of changes that sqlfmt would make to format a file (but not update the file on disk), you can use the `--diff` option. `--diff` also exits with 1 on changes:\n```bash\n$ sqlfmt --diff .\n```\n\n### Disabling sqlfmt\n\nIf you would like sqlfmt to ignore a file, or part of a file, you can add `-- fmt: off` and `-- fmt: on` comments to your code (or `# fmt: off` on MySQL or BigQuery). sqlfmt will not change any code between those comments; a single `-- fmt: off` at the top of a file will keep the entire file intact.\n\n### Using sqlfmt with pre-commit\nYou can configure [pre-commit](https://pre-commit.com/) to run sqlfmt on your repository before you commit changes.\n\nAdd the following config to your `.pre-commit-config.yaml` file:\n\n```\nrepos:\n  - repo: https://github.com/tconbeer/sqlfmt\n    rev: v0.4.3\n    hooks:\n      - id: sqlfmt\n        language_version: python\n```\n\nYou should replace `rev` with the latest available release, but we do suggest pinning to a specific rev, to avoid unexpected formatting changes.\n\n### Using sqlfmt with SQLFluff\n\nYou can (and should!) use SQLFluff to lint your SQL queries after they are formatted by sqlfmt. However, the two tools do not see eye-to-eye on formatting (by default), so to avoid lint errors, add the following to your `.sqlfluff` config file:\n\n```\n[sqlfluff]\nexclude_rules = L003, L018, L036\n\n[sqlfluff:rules]\nmax_line_length = 88  # or whatever you set in sqlfmt\ncapitalisation_policy = lower\nextended_capitalisation_policy = lower\n\n[sqlfluff:indentation]\nindented_joins = False\nindented_using_on = True\ntemplate_blocks_indent = False\n\n[sqlfluff:rules:L052]\nmultiline_newline = True\n```\n\n## The sqlfmt style\nThe only thing you can configure with sqlfmt is the desired line length of the formatted file. You can do this with the `--line-length` or `-l` options. The default is 88.\n\nGiven the desired line length, sqlfmt has four objectives:\n1. Break and indent lines to make the syntactical structure of the code apparent\n2. Break lines so they are shorter than the desired line length, if possible\n3. Combine lines to use the least possible vertical space, without violating #1 and #2\n4. Standardize capitalization (to lowercase) and in-line whitespace\n\nsqlfmt borrows elements from well-accepted styles from other programming languages. It places opening brackets on the same line as preceding function names (like *black* for python and *1TBS* for C). It indents closing brackets to the same depth as the opening bracket (this is extended to statements that must be closed, like `case` and `end`).\n\nThe sqlfmt style is as simple as possible, with little-to-no special-casing of formatting concerns. While at first blush, this may not create a format that is as "nice" or "expressive" as hand-crafted indentation, over time, as you grow accustomed to the style, formatting becomes transparent and the consistency will allow you to jump between files, projects, and even companies much faster.\n\n### Why lowercase?\nThere are several reasons that sqlfmt insists on lowercase SQL keywords:\n1. We believe that SQL is code (this is a surprisingly controversial statement!). Shouting-case keywords perpetuate the myth that SQL isn\'t "real code", or isn\'t "modern" and somehow is trapped in the era of low-level imperative languages: BASIC, COBOL, and FORTRAN. The reality is that SQL is an incredibly powerful, declarative, and modern language. It should look like one\n1. Syntax highlighting for SQL makes shouting-case keywords redundant; the syntax highlighter in any text editor is going to be more consistent than any manual shout-casing. If you have a SQL query as a string inside of a block of code in another language, you may want to capitalize your keywords; sqlfmt only operates on dedicated SQL (and templated sql) files, so this is not relevant. However, even without syntax highlighting, the hierarchical and consistent indentation provided by sqlfmt provides sufficient visual structure without shout-casing keywords\n1. Even among people who like shout-cased keywords, there are disagreements between what gets shout-cased. SELECT, sure, but SUM? AS? OVER? AND? All-lowercase keywords eliminates this potential source of irregularity and disagreement.\n1. Research shows that generally, lowercase words are more readable\n\n### Why trailing commas?\n1. Using trailing commas follows the convention of every other written language and programming language\n1. Leading commas require placing the first field name on the same line as `select`, which can obscure that field\n1. SQL query compilation is extremely fast; the "cost" of "last field" errors is very low. Some dialects (e.g., BigQuery) even allow a trailing comma in the final field of a select statement\n1. Trailing commas generalize better within `select` statements (e.g. `group by` and `partition by` clauses) and in other kinds of SQL statements (e.g. `insert` statements)\n\n### Examples\n\nsqlfmt will put very short queries on a single line:\n\n```sql\nSELECT a,\nb,\n   c\nFROM my_table\n```\nbecomes\n```sql\nselect a, b, c from my_table\n```\n\nIf a query doesn\'t fit on a single line, sqlfmt will format the query to make its hierarchy apparent. The main keywords in a `select` statement are the top nodes in hierarchy. Individual fields are indented a single level; unless all fields fit on the same line as `select`, they must all be individually split onto their own lines. This is properly formatted code:\n```sql\nwith t as (select * from my_schema."my_QUOTED_ table!")\nselect\n    a_long_field_name,\n    another_long_field_name,\n    (one_field + another_field) as c,\n    a_final_field\nfrom t\nwhere one_field < another_field\n```\n\nNote that the main keywords, `with`, `select`, `from`, and `where`, are indented to the same depth. If their arguments fit on a single line (as in `with`, `from`, and `where`), they stay on that line, with the keyword. However, unless all arguments for a keyword fit on one line, they are all wrapped to their own line, and indented:\n\n```sql\nwith\n    a_long_cte_name as (\n        select my_field, sum(another_field) from my_schema."my_QUOTED_ table!"\n    )\nselect\n    a_long_field_name,\n    another_long_field_name,\n    (one_field + another_field) as c,\n    a_final_field\nfrom a_long_cte_name\nwhere\n    one_field < another_field\n    and two_field > another_field\n    and three_field = another_field\n```\n\nAny expressions wrapped in parentheses are similarly one-lined if possible, and split if they are too long.\n\nThis hierarchical indentation scales to arbitrarily complex and nested expressions. Another example of properly formatted code (at line length of 88):\n\n```sql\nselect\n    a,\n    sum(a) over () as b,\n    row_number() over () as c,\n    count(case when a is null then 1 end) over (\n        partition by user_id, date_trunc(\'year\', performed_at)\n    ) as d,\n    first_value(\n        coalesce(one_field, another_field, yet_another_field) ignore nulls\n    ) over (\n        partition by user_id\n        order by performed_at desc\n        rows between unbounded preceding and unbounded following\n    ) as e\nfrom my_table\n```\nWant more examples? See the `tests/data` directory, or go to http://sqlfmt.com to see how sqlfmt will format your queries.\n\n## Contributing\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)\n\n### Setting up Your Dev Environment and Running Tests\n\n1. Install [Poetry](https://python-poetry.org/docs/#installation) if you don\'t have it already. You may also need or want pyenv, make, and gcc. A complete setup from a fresh install of Ubuntu can be found [here](https://github.com/tconbeer/linux_setup)\n1. Clone this repo into a directory (let\'s call it `sqlfmt`), then `cd sqlfmt`\n1. Use `poetry install` to install the project (editable) and its dependencies into a new virtual env. To run `sqlfmt_primer`, you will need to install it (and its dependencies) by specifying it as an extra: `poetry install -E sqlfmt_primer`\n1. Use `poetry shell` to spawn a subshell\n1. Type `make` to run all tests and linters, or run `pytest`, `black`, `flake8`, `isort`, and `mypy` individually.\n\nNote: If encountering a JSONDecodeError during `poetry install`, you will want to clear the poetry cache with `poetry cache clear pypi --all`.\n',
    'author': 'Ted Conbeer',
    'author_email': 'ted@shandy.io',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'http://sqlfmt.com',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
